# update-copyright [![NPM version](https://img.shields.io/npm/v/update-copyright.svg?style=flat)](https://www.npmjs.com/package/update-copyright) [![NPM monthly downloads](https://img.shields.io/npm/dm/update-copyright.svg?style=flat)](https://npmjs.org/package/update-copyright) [![NPM total downloads](https://img.shields.io/npm/dt/update-copyright.svg?style=flat)](https://npmjs.org/package/update-copyright) [![Linux Build Status](https://img.shields.io/travis/jonschlinkert/update-copyright.svg?style=flat&label=Travis)](https://travis-ci.org/jonschlinkert/update-copyright)

> Update a copyright statement with the current year. Also makes minor corrections.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save update-copyright
```

## Usage

```js
copyright(string, options);
```

Pass a string with a copyright statement to update, and it will be parsed and updated.

```js
var copyright = require('update-copyright');

copyright('Copyright (c) 2015, Jon Schlinkert.');
//=> 'Copyright (c) 2015-2016, Jon Schlinkert.'

copyright('Copyright (c) 2012, 2015, Jon Schlinkert.');
//=> 'Copyright (c) 2012, 2015-2016, Jon Schlinkert.'
```

The [current year](https://github.com/jonschlinkert/update-year) is updated/appended to existing years. The rest of the information will stay the same unless new information is passed.

### Lazy mode

If you're too lazy to pass anything at all, that's okay! You get a free copyright statement with the current year, using data from package.json!

```js
copyright();
//=> 'Copyright (c) 2016, Jon Schlinkert.'
```

### Optionally fills in author

**Example**

If the author is missing it will be filled in with the author from package.json.

```js
copyright('Copyright (c) 2014.');
//=> 'Copyright (c) 2014-2015, Jon Schlinkert.'
```

### Fixes Misspellings

It will use the author from package.json if a misspelling seems obvious (according to its [Levenshtein distance](https://en.wikipedia.org/wiki/Levenshtein_distance)):

```js
copyright('Copyright (c) 2014, Jon Shlinert');
//=> 'Copyright (c) 2014, 2016, Jon Schlinkert.'
```

See [the tests](./tests.js) for more examples.

## Options

A template is used to create the new copyright statement, and the options object is merged with the context that is passed to the template.

### context

1. The (context) object is populated with data from the parsed (old) copyright statement
2. The object is then updated with the current year, author from package.json, and any other data you pass on the options.

**Custom context**

This is what the context object looks like. To override anything on the context just pass the property and value on the options:

```js
{ year: '2015',
  prefix: 'Copyright',
  symbol: '(c)',
  template: '<%= prefix %><%= symbol ? (" " + symbol + " ") : "" %><%= years %>, <%= authors %>.',
  statement: 'Copyright (c) 2015, Jon Schlinkert',
  dateRange: '2014',
  latest: '2014',
  author: 'Jon Schlinkert' }
```

**Example**

Pass any custom data (as shown above) on the options:

```js
copyright('Copyright (c) 2015.', {author: 'Foo Bar'});
//=> 'Copyright (c) 2015-2016, Foo Bar.'
```

## About

### Related projects

* [copyright-regex](https://www.npmjs.com/package/copyright-regex): Regex for matching and parsing copyright statements. | [homepage](https://github.com/regexhq/copyright-regex "Regex for matching and parsing copyright statements.")
* [parse-copyright](https://www.npmjs.com/package/parse-copyright): Parse copyright statement(s) into an array of copyright objects. | [homepage](https://github.com/jonschlinkert/parse-copyright "Parse copyright statement(s) into an array of copyright objects.")
* [update-year](https://www.npmjs.com/package/update-year): Update or add the current year to a range of years in a string. | [homepage](https://github.com/jonschlinkert/update-year "Update or add the current year to a range of years in a string.")
* [update](https://www.npmjs.com/package/update): Be scalable! Update is a new, open source developer framework and CLI for automating updates… [more](https://github.com/update/update) | [homepage](https://github.com/update/update "Be scalable! Update is a new, open source developer framework and CLI for automating updates of any kind in code projects.")
* [year](https://www.npmjs.com/package/year): Simple utility to get the current year with 2 or 4 digits. | [homepage](https://github.com/jonschlinkert/year "Simple utility to get the current year with 2 or 4 digits.")

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Contributors

| **Commits** | **Contributor** | 
| --- | --- |
| 38 | [jonschlinkert](https://github.com/jonschlinkert) |
| 1 | [david-w-millar](https://github.com/david-w-millar) |

### Building docs

_(This project's readme.md is generated by [verb](https://github.com/verbose/verb-generate-readme), please don't edit the readme directly. Any changes to the readme must be made in the [.verb.md](.verb.md) readme template.)_

To generate the readme, run the following command:

```sh
$ npm install -g verbose/verb#dev verb-generate-readme && verb
```

### Running tests

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](https://twitter.com/jonschlinkert)

### License

Copyright © 2017, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on June 26, 2017._